Developers | Chart.js
Description: Open source HTML5 Charts for your website

# # Developers

Developer features allow extending and enhancing Chart.js in many different ways.

## # Latest resources

Latest documentation and samples, including unreleased features, are available at:

- https://www.chartjs.org/docs/master/
  (opens new window)
- https://www.chartjs.org/samples/master/
  (opens new window)

## # Development releases

Latest builds are available for testing at:

- https://www.chartjs.org/dist/master/chart.js
  (opens new window)
- https://www.chartjs.org/dist/master/chart.min.js
  (opens new window)

WARNING: Development builds MUST not be used for production purposes or as replacement for CDN.

## # Browser support

All modern and up-to-date browsers are supported, including, but not limited to:

Chrome Edge Firefox Safari

As of version 3, we have dropped Internet Explorer 11 support.

Browser support for the canvas element is available in all modern & major mobile browsers. CanIUse
(opens new window)

Run `npx browserslist` at the root of the codebase
(opens new window) to get a list of supported browsers.

Thanks to BrowserStack
(opens new window) for allowing our team to test on thousands of browsers.

## # Previous versions

To migrate from version 2 to version 3, please see the v3 migration guide.

Version 3 has a largely different API than earlier versions.

Most earlier version options have current equivalents or are the same.

Please note - documentation for previous versions is available online or in the GitHub repo.

- 2.9.4 Documentation
  (opens new window)
- 1.x Documentation
  (opens new window)